go_mruby

package module
v1.0.0-beta7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2021 License: MIT Imports: 1 Imported by: 0

README

mruby module for Go

This Go package let you use mruby interpreter. We use mruby C librarary (clone from https://github.com/mruby/mruby). Mruby license is included and you can find it in file mruby/LICENSE (MIT license). First step: get package by using go get:

go get webimizer.dev/go_mruby

IMPORTANT: When you run go get command you may get error. To fix that, you need to copy file libmruby.a to your project root directory. Example bash command to run on your project root directory:

export GOPATH=$(go env GOPATH)
cp $GOPATH/pkg/mod/webimizer.dev/go_mruby@v1.0.0-beta7/mruby/libmruby.a ./mruby/libmruby.a

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Mruby_load_from_string

func Mruby_load_from_string(code string)

Types

This section is empty.

Jump to